#!/bin/bash
   docker compose up -d \
&& docker compose exec app dashboard auth add-user mv 12345yes \
&& docker compose exec app mkdir -p /root/.developer-dashboard/dashboards/public/js \
&& docker compose exec -w /root/.developer-dashboard/dashboards/public/js app bash -c 'curl https://code.jquery.com/jquery-4.0.0.min.js > jq.js' \
&& docker compose cp test.bookmark app:/root/.developer-dashboard/dashboards/test \
&& docker compose cp index.bookmark app:/root/.developer-dashboard/dashboards/index \
&& docker compose exec -w /root/.developer-dashboard app bash
